@@ -3,12 +3,14 @@ Evaluate a python string as code
 """
 import importlib.machinery
 import importlib.util
-import tempfile
 import os
+import tempfile
+import functools
 
 
+@functools.lru_cache(None)
 def eval_code(code):
-    """
+    r"""
     save code in a temporary file and import it as a module
     """
     new_file, filename = tempfile.mkstemp(text=True)
